%define fedora 19
Name:		bdii
Version:	5.2.17
Release:	alt1_2
Summary:	The Berkeley Database Information Index (BDII)

Group:		System/Servers
License:	ASL 2.0
URL:		https://twiki.cern.ch/twiki/bin/view/EGEE/BDII
#		The source for this package was pulled from upstream's vcs.
#		Use the following commands to generate the tarball:
#		svn export http://svnweb.cern.ch/guest/gridinfo/bdii/tags/R_5_2_17 %{name}-%{version}
#		tar -z -c -f %{name}-%{version}.tar.gz %{name}-%{version}
Source:		%{name}-%{version}.tar.gz
BuildArch:	noarch

Requires:	openldap-clients
Requires:	openldap-servers
%if "%{?rhel}" == "5"
#		The rwm overlay is in a separate package in RHEL 5
Requires:	openldap-servers-overlays
%endif
Requires:	glue-schema >= 2.0.10

Requires(post):		chkconfig
Requires(post):		expect
Requires(preun):	chkconfig

%if %{?fedora}%{!?fedora:0} >= 5 || %{?rhel}%{!?rhel:0} >= 5
Requires(post):		policycoreutils
Requires(postun):	policycoreutils
%if %{?fedora}%{!?fedora:0} >= 11 || %{?rhel}%{!?rhel:0} >= 6
Requires(post): policycoreutils
Requires(postun): policycoreutils
%endif
%endif
Source44: import.info

%description
The Berkeley Database Information Index (BDII) consists of a standard
LDAP database which is updated by an external process. The update process
obtains LDIF from a number of sources and merges them. It then compares
this to the contents of the database and creates an LDIF file of the
differences. This is then used to update the database.

%prep
%setup -q

%build

%install
make install prefix=%{buildroot}

chmod 644 %{buildroot}%{_sysconfdir}/sysconfig/%{name}

%if "%{?rhel}" == "5"
# slapd in RHEL 5 had the relay backend compiled in and doesn't need to load it
# slapd in RHEL 5 doesn't look in /usr/lib(64)?/openldap for modules by default
sed -e '/moduleload back_relay/d' \
    -e '/moduleload rwm/imodulepath /usr/lib/openldap' \
    -e '/moduleload rwm/imodulepath /usr/lib64/openldap' \
    -i %{buildroot}%{_sysconfdir}/%{name}/*-slapd.conf
%endif

mkdir -p $RPM_BUILD_ROOT`dirname /etc/default/bdii`
touch $RPM_BUILD_ROOT/etc/default/bdii

%pre
service %{name} status > /dev/null 2>&1
if [ $? -eq 0 ]; then
  touch %{_var}/run/%{name}/bdii.upgrade
  service %{name} stop > /dev/null 2>&1
fi

%post
sed "s/\(rootpw *\)secret/\1$(mkpasswd -s 0 | tr '/' 'x')/" \
    -i %{_sysconfdir}/%{name}/bdii-slapd.conf \
       %{_sysconfdir}/%{name}/bdii-top-slapd.conf

# Temp fix for upgrade from 5.2.5 to 5.2.7
if [ -f %{_var}/run/%{name}/bdii.upgrade ]; then
  rm -f %{_var}/run/%{name}/bdii.upgrade
  service %{name} start > /dev/null 2>&1
fi

/sbin/chkconfig --add %{name}

%if %{?fedora}%{!?fedora:0} >= 5 || %{?rhel}%{!?rhel:0} >= 5
semanage port -a -t ldap_port_t -p tcp 2170 2>/dev/null || :
semanage fcontext -a -t slapd_db_t "%{_var}/lib/%{name}/db(/.*)?" 2>/dev/null || :
semanage fcontext -a -t slapd_var_run_t "%{_var}/run/%{name}/db(/.*)?" 2>/dev/null || :
# Remove selinux labels for old bdii var dir
semanage fcontext -d -t slapd_db_t "%{_var}/run/%{name}(/.*)?" 2>/dev/null || :
%endif

%preun
if [ $1 -eq 0 ]; then
  service %{name} stop > /dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi

%postun
if [ $1 -ge 1 ]; then
  service %{name} condrestart > /dev/null 2>&1
fi
%if %{?fedora}%{!?fedora:0} >= 5 || %{?rhel}%{!?rhel:0} >= 5
if [ $1 -eq 0 ]; then
  semanage port -d -t ldap_port_t -p tcp 2170 2>/dev/null || :
  semanage fcontext -d -t slapd_db_t "%{_var}/lib/%{name}/db(/.*)?" 2>/dev/null || :
  semanage fcontext -d -t slapd_var_run_t "%{_var}/run/%{name}/db(/.*)?" 2>/dev/null || :
fi
%endif

%files
%attr(-,ldap,ldap) %{_var}/lib/%{name}
%attr(-,ldap,ldap) %{_var}/log/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/DB_CONFIG
%config(noreplace) %{_sysconfdir}/%{name}/DB_CONFIG_top
%config(noreplace) %{_sysconfdir}/%{name}/bdii.conf
%config(noreplace) %{_sysconfdir}/%{name}/BDII.schema
%attr(-,ldap,ldap) %config %{_sysconfdir}/%{name}/bdii-slapd.conf
%attr(-,ldap,ldap) %config %{_sysconfdir}/%{name}/bdii-top-slapd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_initrddir}/%{name}
%{_sbindir}/bdii-update
%{_mandir}/man1/bdii-update.1*
%doc copyright
%config(noreplace,missingok) /etc/default/bdii

%changelog
* Thu May 02 2013 Igor Vlasenko <viy@altlinux.ru> 5.2.17-alt1_2
- initial fc import

